==> openGion_dev_5.6.3.0.zip: opengion/uap/webapps/gf/src/org/opengion/plugin/query/Query_JDBC.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.query;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

import org.opengion.fukurou.util.Closer;
import org.opengion.fukurou.util.ErrorMessage;
import org.opengion.hayabusa.common.HybsSystem;
import org.opengion.hayabusa.common.HybsSystemException;
import org.opengion.hayabusa.db.AbstractQuery;

/**
 * 指定のSQL文を実行して、検索する Query クラスです。
 *
 * java.sql.Statement を用いて、データベース検索処理を行います。
 * 引数は無しです。(与えられたSQL文を実行します。)
 * 内部変数の受け渡しのデフォルト実装は、AbstractQuery クラスを継承している
 * ため,ここでは、execute() メソッドを実装しています。
 * このクラスでは、ステートメント文を execute() する事により,データベースを
 * 検索した結果を DBTableModel に割り当てます。
 *
 * @og.formSample
 * &lt;og:query command=&quot;{&#064;command}&quot; debug=&quot;false&quot;&gt;
 *     &lt;!-- 先頭のカラム名が、&quot;WRITABLE&quot; の場合、&#39;true&#39; or &#39;1&#39; で、書き込み許可が与えら,&#39;2&#39; でチェック済みになります。--&gt;
 *         select KBSAKU AS WRITABLE,
 *                 CLM,NAME_JA,LABEL_NAME,KBSAKU,SYSTEM_ID,LANG,FGJ
 *         from GE41
 *     &lt;og:where&gt;
 *         &lt;og:and value = &quot;FGJ         in  (&#39;0&#39;,&#39;1&#39;)&quot;         /&gt;
 *         &lt;og:and value = &quot;SYSTEM_ID   like &#39;{&#064;SYSTEM_ID}%&#39;&quot;  /&gt;
 *         &lt;og:and value = &quot;LANG        like &#39;{&#064;LANG}%&#39;&quot;       /&gt;
 *         &lt;og:and value = &quot;CLM         like &#39;{&#064;CLM}%&#39;&quot;        /&gt;
 *         &lt;og:and value = &quot;KBSAKU      =    &#39;{&#064;KBSAKU}&#39;&quot;      /&gt;
 *     &lt;/og:where&gt;
 *     &lt;og:appear startKey = &quot;order by&quot; value = &quot;{&#064;ORDER_BY}&quot;
 *                 defaultVal = &quot;SYSTEM_ID,CLM,LANG&quot; /&gt;
 * &lt;/og:query&gt;
 *
 * @og.group データ表示
 * @og.group データ編集
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class Query_JDBC extends AbstractQuery {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "4.0.0 (2005/08/31)" ;

	/**
	 * クエリーを実行します。
	 * セットされているステートメント文字列とそのタイプが合っていない場合は,
	 * エラーになります。
	 * 実行結果は、DBTableModel にセットされます。
	 *
	 * @og.rev 3.8.0.8 (2005/10/03) エラーメッセージの出力順をメッセージ＋Queryに変更します。
	 *
	 */
	@Override
	public void execute() {
		Statement stmt = null ;
		ResultSet resultSet = null ;
		try {
			stmt = getConnection().createStatement();
			stmt.setQueryTimeout( DB_MAX_QUERY_TIMEOUT );

			boolean status = stmt.execute( getStatement() );

			if( status ) {
				resultSet = stmt.getResultSet();
				createTableModel( resultSet );
				setUpdateFlag( false );
			}
			else {
				setExecuteCount( stmt.getUpdateCount() );
			}
			setErrorCode( ErrorMessage.OK );
		}
		catch ( SQLException ex ) {
			setErrorCode( ErrorMessage.EXCEPTION );
			String errMsg = ex.getMessage() + ":" + ex.getSQLState() + HybsSystem.CR
						+ getStatement() + HybsSystem.CR;
			rollback();
			realClose();
			throw new HybsSystemException( errMsg,ex );		// 3.5.5.4 (2004/04/15) 引数の並び順変更
		}
		finally {
			Closer.resultClose( resultSet );
			Closer.stmtClose( stmt );
		}
	}
}

==> openGion_dev_5.10.23.0.zip: opengion/uap/webapps/gf/src/org/opengion/plugin/query/Query_JDBC.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.query;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

import org.opengion.fukurou.util.Closer;
import org.opengion.fukurou.util.ErrorMessage;
import org.opengion.hayabusa.common.HybsSystem;
import org.opengion.hayabusa.common.HybsSystemException;
import org.opengion.hayabusa.db.AbstractQuery;

/**
 * 指定のSQL文を実行して、検索する Query クラスです。
 *
 * java.sql.Statement を用いて、データベース検索処理を行います。
 * 引数は無しです。(与えられたSQL文を実行します。)
 * 内部変数の受け渡しのデフォルト実装は、AbstractQuery クラスを継承している
 * ため,ここでは、execute() メソッドを実装しています。
 * このクラスでは、ステートメント文を execute() する事により,データベースを
 * 検索した結果を DBTableModel に割り当てます。
 *
 * @og.formSample
 * &lt;og:query command=&quot;{&#064;command}&quot; debug=&quot;false&quot;&gt;
 *     &lt;!-- 先頭のカラム名が、&quot;WRITABLE&quot; の場合、&#39;true&#39; or &#39;1&#39; で、書き込み許可が与えら,&#39;2&#39; でチェック済みになります。--&gt;
 *         select KBSAKU AS WRITABLE,
 *                 CLM,NAME_JA,LABEL_NAME,KBSAKU,SYSTEM_ID,LANG,FGJ
 *         from GE41
 *     &lt;og:where&gt;
 *         &lt;og:and value = &quot;FGJ         in  (&#39;0&#39;,&#39;1&#39;)&quot;         /&gt;
 *         &lt;og:and value = &quot;SYSTEM_ID   like &#39;{&#064;SYSTEM_ID}%&#39;&quot;  /&gt;
 *         &lt;og:and value = &quot;LANG        like &#39;{&#064;LANG}%&#39;&quot;       /&gt;
 *         &lt;og:and value = &quot;CLM         like &#39;{&#064;CLM}%&#39;&quot;        /&gt;
 *         &lt;og:and value = &quot;KBSAKU      =    &#39;{&#064;KBSAKU}&#39;&quot;      /&gt;
 *     &lt;/og:where&gt;
 *     &lt;og:appear startKey = &quot;order by&quot; value = &quot;{&#064;ORDER_BY}&quot;
 *                 defaultVal = &quot;SYSTEM_ID,CLM,LANG&quot; /&gt;
 * &lt;/og:query&gt;
 *
 * @og.group データ表示
 * @og.group データ編集
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class Query_JDBC extends AbstractQuery {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "4.0.0.0 (2005/08/31)" ;

	/**
	 * クエリーを実行します。
	 * セットされているステートメント文字列とそのタイプが合っていない場合は,
	 * エラーになります。
	 * 実行結果は、DBTableModel にセットされます。
	 *
	 * @og.rev 3.8.0.8 (2005/10/03) エラーメッセージの出力順をメッセージ＋Queryに変更します。
	 *
	 */
	@Override
	public void execute() {
		Statement stmt = null ;
		ResultSet resultSet = null ;
		try {
			stmt = getConnection().createStatement();
			stmt.setQueryTimeout( DB_MAX_QUERY_TIMEOUT );

			boolean status = stmt.execute( getStatement() );

			if( status ) {
				resultSet = stmt.getResultSet();
				createTableModel( resultSet );
				setUpdateFlag( false );
			}
			else {
				setExecuteCount( stmt.getUpdateCount() );
			}
			setErrorCode( ErrorMessage.OK );
		}
		catch ( SQLException ex ) {
			setErrorCode( ErrorMessage.EXCEPTION );
			String errMsg = ex.getMessage() + ":" + ex.getSQLState() + HybsSystem.CR
						+ getStatement() + HybsSystem.CR;
			rollback();
			realClose();
			throw new HybsSystemException( errMsg,ex );		// 3.5.5.4 (2004/04/15) 引数の並び順変更
		}
		finally {
			Closer.resultClose( resultSet );
			Closer.stmtClose( stmt );
		}
	}
}
